/***************************************************************************
 $RCSfile$
 -------------------
 cvs         : $Id: country_l.h 214 2005-02-17 07:54:40Z aquamaniac $
 begin       : Mon Mar 01 2004
 copyright   : (C) 2004 by Martin Preuss
 email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/


#ifndef AQBANKING_COUNTRY_L_H
#define AQBANKING_COUNTRY_L_H

#include <aqbanking/country.h>


const AB_COUNTRY *AB_Country_FindByName(const char *name);
const AB_COUNTRY *AB_Country_FindByLocalName(const char *name);
const AB_COUNTRY *AB_Country_FindByCode(const char *code);
const AB_COUNTRY *AB_Country_FindByNumeric(int numid);

AB_COUNTRY_CONSTLIST2 *AB_Country_ListByName(const char *name);
AB_COUNTRY_CONSTLIST2 *AB_Country_ListByLocalName(const char *name);

#endif /* AQBANKING_COUNTRY_L_H */
